@@ -5,8 +5,7 @@ use warnings;
 use base qw( Alien::Base );
 
 # ABSTRACT: Install the C libxml2 library on your system
-our $VERSION = '0.18_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '0.20'; # VERSION
 
 
 
@@ -25,7 +24,7 @@ Alien::Libxml2 - Install the C libxml2 library on your system
 
 =head1 VERSION
 
-version 0.18_01
+version 0.20
 
 =head1 SYNOPSIS
 
@@ -111,9 +110,11 @@ Contributors:
 
 Shlomi Fish (shlomif)
 
+Shawn Laffan (SLAFFAN)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013-2022 by Graham Ollis.
+This software is copyright (c) 2013-2024 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
